==> ldap-account-manager_5.2.orig.tar.bz2: ldap-account-manager-5.2/templates/lib/extra/ckeditor/plugins/link/lang/hi.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'hi', {
	acccessKey: 'ऍक्सॅस की',
	advanced: 'ऍड्वान्स्ड',
	advisoryContentType: 'परामर्श कन्टॅन्ट प्रकार',
	advisoryTitle: 'परामर्श शीर्शक',
	anchor: {
		toolbar: 'ऐंकर इन्सर्ट/संपादन',
		menu: 'ऐंकर प्रॉपर्टीज़',
		title: 'ऐंकर प्रॉपर्टीज़',
		name: 'ऐंकर का नाम',
		errorName: 'ऐंकर का नाम टाइप करें',
		remove: 'Remove Anchor'
	},
	anchorId: 'ऍलीमॅन्ट Id से',
	anchorName: 'ऐंकर नाम से',
	charset: 'लिंक रिसोर्स करॅक्टर सॅट',
	cssClasses: 'स्टाइल-शीट क्लास',
	emailAddress: 'ई-मेल पता',
	emailBody: 'संदेश',
	emailSubject: 'संदेश विषय',
	id: 'Id',
	info: 'लिंक  ',
	langCode: 'भाषा लिखने की दिशा',
	langDir: 'भाषा लिखने की दिशा',
	langDirLTR: 'बायें से दायें (LTR)',
	langDirRTL: 'दायें से बायें (RTL)',
	menu: 'लिंक संपादन',
	name: 'नाम',
	noAnchors: '(डॉक्यूमॅन्ट में ऐंकर्स की संख्या)',
	noEmail: 'ई-मेल पता टाइप करें',
	noUrl: 'लिंक URL टाइप करें',
	other: '<अन्य>',
	popupDependent: 'डिपेन्डॅन्ट (Netscape)',
	popupFeatures: 'पॉप-अप विन्डो फ़ीचर्स',
	popupFullScreen: 'फ़ुल स्क्रीन (IE)',
	popupLeft: 'बायीं तरफ',
	popupLocationBar: 'लोकेशन बार',
	popupMenuBar: 'मॅन्यू बार',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'स्क्रॉल बार',
	popupStatusBar: 'स्टेटस बार',
	popupToolbar: 'टूल बार',
	popupTop: 'दायीं तरफ',
	rel: 'Relationship', // MISSING
	selectAnchor: 'ऐंकर चुनें',
	styles: 'स्टाइल',
	tabIndex: 'टैब इन्डॅक्स',
	target: 'टार्गेट',
	targetFrame: '<फ़्रेम>',
	targetFrameName: 'टार्गेट फ़्रेम का नाम',
	targetPopup: '<पॉप-अप विन्डो>',
	targetPopupName: 'पॉप-अप विन्डो का नाम',
	title: 'लिंक',
	toAnchor: 'इस पेज का ऐंकर',
	toEmail: 'ई-मेल',
	toUrl: 'URL',
	toolbar: 'लिंक इन्सर्ट/संपादन',
	type: 'लिंक प्रकार',
	unlink: 'लिंक हटायें',
	upload: 'अपलोड'
} );

==> ldap-account-manager_7.5.orig.tar.bz2: ldap-account-manager-7.5/templates/lib/extra/ckeditor/plugins/link/lang/hi.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'hi', {
	acccessKey: 'ऍक्सॅस की',
	advanced: 'ऍड्वान्स्ड',
	advisoryContentType: 'परामर्श कन्टॅन्ट प्रकार',
	advisoryTitle: 'परामर्श शीर्शक',
	anchor: {
		toolbar: 'ऐंकर इन्सर्ट/संपादन',
		menu: 'ऐंकर प्रॉपर्टीज़',
		title: 'ऐंकर प्रॉपर्टीज़',
		name: 'ऐंकर का नाम',
		errorName: 'ऐंकर का नाम टाइप करें',
		remove: 'Remove Anchor'
	},
	anchorId: 'ऍलीमॅन्ट Id से',
	anchorName: 'ऐंकर नाम से',
	charset: 'लिंक रिसोर्स करॅक्टर सॅट',
	cssClasses: 'स्टाइल-शीट क्लास',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'ई-मेल पता',
	emailBody: 'संदेश',
	emailSubject: 'संदेश विषय',
	id: 'Id',
	info: 'लिंक  ',
	langCode: 'भाषा लिखने की दिशा',
	langDir: 'भाषा लिखने की दिशा',
	langDirLTR: 'बायें से दायें (LTR)',
	langDirRTL: 'दायें से बायें (RTL)',
	menu: 'लिंक संपादन',
	name: 'नाम',
	noAnchors: '(डॉक्यूमॅन्ट में ऐंकर्स की संख्या)',
	noEmail: 'ई-मेल पता टाइप करें',
	noUrl: 'लिंक URL टाइप करें',
	other: '<अन्य>',
	popupDependent: 'डिपेन्डॅन्ट (Netscape)',
	popupFeatures: 'पॉप-अप विन्डो फ़ीचर्स',
	popupFullScreen: 'फ़ुल स्क्रीन (IE)',
	popupLeft: 'बायीं तरफ',
	popupLocationBar: 'लोकेशन बार',
	popupMenuBar: 'मॅन्यू बार',
	popupResizable: 'आकार बदलने लायक',
	popupScrollBars: 'स्क्रॉल बार',
	popupStatusBar: 'स्टेटस बार',
	popupToolbar: 'टूल बार',
	popupTop: 'दायीं तरफ',
	rel: 'संबंध',
	selectAnchor: 'ऐंकर चुनें',
	styles: 'स्टाइल',
	tabIndex: 'टैब इन्डॅक्स',
	target: 'टार्गेट',
	targetFrame: '<फ़्रेम>',
	targetFrameName: 'टार्गेट फ़्रेम का नाम',
	targetPopup: '<पॉप-अप विन्डो>',
	targetPopupName: 'पॉप-अप विन्डो का नाम',
	title: 'लिंक',
	toAnchor: 'इस पेज का ऐंकर',
	toEmail: 'ई-मेल',
	toUrl: 'URL',
	toolbar: 'लिंक इन्सर्ट/संपादन',
	type: 'लिंक प्रकार',
	unlink: 'लिंक हटायें',
	upload: 'अपलोड'
} );
